@@ -1,6 +1,6 @@
-from .SimConnect import SimConnect, Request, Event, millis, DWORD
-from .RequestList import AircraftRequests
-from .EventList import AircraftEvents
+from .SimConnect import SimConnect, millis, DWORD
+from .RequestList import AircraftRequests, Request
+from .EventList import AircraftEvents, Event
 
 
 def int_or_str(value):
@@ -10,7 +10,7 @@ def int_or_str(value):
 		return value
 
 
-__version__ = "0.4.1"
+__version__ = "0.4.2"
 VERSION = tuple(map(int_or_str, __version__.split(".")))
 
 __all__ = ["SimConnect", "Request", "Event", "millis", "DWORD", "AircraftRequests", "AircraftEvents"]
